# Changelog

## [0.1.0] - 2025-02-12

### Added
- Initial release
- 10 MCP tools for Tuya device control
- 1 MCP resource for device listing
- Device name resolution (use friendly names instead of IDs)
- Intelligent caching with configurable TTL
- Support for `uvx`, `pip`, and `pipx` installation
- Claude Desktop and Claude Code integration
- Support for all Tuya API regions (EU, US, CN, IN)
